.. ufs2arco documentation master file, created by
   sphinx-quickstart on Wed Nov 15 16:50:45 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ufs2arco
========

Tools for converting Unified Forecast System (UFS) output to Analysis Ready, Cloud Optimized (ARCO) format

.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   installation
   capability_overview
   moving_data

.. toctree::
   :maxdepth: 1
   :caption: Data Sources

   gefs_archive
   gfs_archive
   hrrr_archive

.. toctree::
   :maxdepth: 1
   :caption: Examples

   Interpolate FV3 to Pressure Levels <example_pressure_interpolation>

.. toctree::
   :maxdepth: 1
   :caption: Community

   contributing
   support

.. toctree::
   :maxdepth: 1
   :caption: References

   api
